@@ -1,10 +1,10 @@
-# @(#)$Id: Constants.pm 1320 2013-07-31 17:31:20Z pjf $
+# @(#)Ident: ;
 
 package CatalystX::Usul::Constants;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 1320 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 0 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants ();
 use Sub::Exporter;
@@ -68,7 +68,7 @@ CatalystX::Usul::Constants - Definitions of constant values
 
 =head1 Version
 
-0.8.$Rev: 1320 $
+Describes v0.9.$Rev: 0 $
 
 =head1 Synopsis
 
