@@ -1,9 +1,9 @@
-# @(#)$Id: Process.pm 1320 2013-07-31 17:31:20Z pjf $
+# @(#)Ident: ;
 
 package CatalystX::Usul::Model::Process;
 
 use strict;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 1320 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 0 $ =~ /\d+/gmx );
 
 use CatalystX::Usul::Moose;
 use Class::Usul::IPC;
@@ -175,7 +175,7 @@ CatalystX::Usul::Model::Process - View and signal processes
 
 =head1 Version
 
-0.8.$Revision: 1320 $
+Describes v0.9.$Rev: 0 $
 
 =head1 Synopsis
 
