@@ -1,9 +1,9 @@
-# @(#)$Id: Schema.pm 1320 2013-07-31 17:31:20Z pjf $
+# @(#)Ident: ;
 
 package CatalystX::Usul::Schema;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 1320 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 0 $ =~ /\d+/gmx );
 
 use CatalystX::Usul::Constants;
 use CatalystX::Usul::Functions qw( distname );
@@ -323,6 +323,8 @@ sub _run_db_cmd {
 
 1;
 
+__END__
+
 =pod
 
 =head1 Name
@@ -331,7 +333,7 @@ CatalystX::Usul::Schema - Support for database schemas
 
 =head1 Version
 
-0.8.$Revision: 1320 $
+Describes v0.9.$Rev: 0 $
 
 =head1 Synopsis
 
