@@ -1,10 +1,10 @@
-# @(#)$Id: StashHelper.pm 1320 2013-07-31 17:31:20Z pjf $
+# @(#)Ident: StashHelper.pm 2013-08-19 19:34 pjf ;
 
 package CatalystX::Usul::TraitFor::Model::StashHelper;
 
-use 5.01;
+use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 1320 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 0 $ =~ /\d+/gmx );
 
 use CatalystX::Usul::Constants;
 use CatalystX::Usul::Functions qw( assert exception is_arrayref is_hashref
@@ -711,7 +711,7 @@ CatalystX::Usul::TraitFor::Model::StashHelper - Convenience methods for stuffing
 
 =head1 Version
 
-0.8.$Revision: 1320 $
+Describes v0.9.$Rev: 0 $
 
 =head1 Synopsis
 
